summaryrefslogtreecommitdiff
path: root/vcl/generic
diff options
context:
space:
mode:
authorNorbert Thiebaud <nthiebaud@gmail.com>2012-06-19 06:24:37 -0500
committerMiklos Vajna <vmiklos@suse.cz>2012-06-20 11:00:22 +0200
commit2bbebea59de3e2e22817ed4fbe0ce7b7df7c0342 (patch)
tree9f8271e3b701c2161cee29d1418d26b7b235a6c6 /vcl/generic
parentbb6fec1bd39be9f6d660623abd2b25400a34b9ac (diff)
Rename the class ImplFontData into PhysicalFontFace
Change-Id: I402481e7c6ea605c8ccfdf6cb08166859b37e8de
Diffstat (limited to 'vcl/generic')
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.cxx2
-rw-r--r--vcl/generic/glyphs/gcach_ftyp.hxx6
-rw-r--r--vcl/generic/glyphs/glyphcache.cxx2
-rw-r--r--vcl/generic/print/genpspgraphics.cxx24
4 files changed, 17 insertions, 17 deletions
diff --git a/vcl/generic/glyphs/gcach_ftyp.cxx b/vcl/generic/glyphs/gcach_ftyp.cxx
index 9cd88a47c3ab..9da899388ef3 100644
--- a/vcl/generic/glyphs/gcach_ftyp.cxx
+++ b/vcl/generic/glyphs/gcach_ftyp.cxx
@@ -640,7 +640,7 @@ ServerFont* FreetypeManager::CreateFont( const FontSelectPattern& rFSD )
// =======================================================================
ImplFTSFontData::ImplFTSFontData( FtFontInfo* pFI, const ImplDevFontAttributes& rDFA )
-: ImplFontData( rDFA, IFTSFONT_MAGIC ),
+: PhysicalFontFace( rDFA, IFTSFONT_MAGIC ),
mpFtFontInfo( pFI )
{
mbDevice = false;
diff --git a/vcl/generic/glyphs/gcach_ftyp.hxx b/vcl/generic/glyphs/gcach_ftyp.hxx
index 79926726be22..0bd38e63eed3 100644
--- a/vcl/generic/glyphs/gcach_ftyp.hxx
+++ b/vcl/generic/glyphs/gcach_ftyp.hxx
@@ -176,7 +176,7 @@ private:
// -----------------------------------------------------------------------
-class ImplFTSFontData : public ImplFontData
+class ImplFTSFontData : public PhysicalFontFace
{
private:
FtFontInfo* mpFtFontInfo;
@@ -188,10 +188,10 @@ public:
FtFontInfo* GetFtFontInfo() const { return mpFtFontInfo; }
virtual ImplFontEntry* CreateFontInstance( FontSelectPattern& ) const;
- virtual ImplFontData* Clone() const { return new ImplFTSFontData( *this ); }
+ virtual PhysicalFontFace* Clone() const { return new ImplFTSFontData( *this ); }
virtual sal_IntPtr GetFontId() const { return mpFtFontInfo->GetFontId(); }
- static bool CheckFontData( const ImplFontData& r ) { return r.CheckMagic( IFTSFONT_MAGIC ); }
+ static bool CheckFontData( const PhysicalFontFace& r ) { return r.CheckMagic( IFTSFONT_MAGIC ); }
};
// -----------------------------------------------------------------------
diff --git a/vcl/generic/glyphs/glyphcache.cxx b/vcl/generic/glyphs/glyphcache.cxx
index b48b4158cf1e..66dc23760ed7 100644
--- a/vcl/generic/glyphs/glyphcache.cxx
+++ b/vcl/generic/glyphs/glyphcache.cxx
@@ -211,7 +211,7 @@ ServerFont* GlyphCache::CacheFont( const FontSelectPattern& rFontSelData )
// the FontList's key mpFontData member is reinterpreted as font id
FontSelectPattern aFontSelData = rFontSelData;
- aFontSelData.mpFontData = reinterpret_cast<ImplFontData*>( nFontId );
+ aFontSelData.mpFontData = reinterpret_cast<PhysicalFontFace*>( nFontId );
FontList::iterator it = maFontList.find( aFontSelData );
if( it != maFontList.end() )
{
diff --git a/vcl/generic/print/genpspgraphics.cxx b/vcl/generic/print/genpspgraphics.cxx
index 95aed990e218..78a6c1e046b6 100644
--- a/vcl/generic/print/genpspgraphics.cxx
+++ b/vcl/generic/print/genpspgraphics.cxx
@@ -544,7 +544,7 @@ void GenPspGraphics::invert(long,long,long,long,SalInvert)
//==========================================================================
-class ImplPspFontData : public ImplFontData
+class ImplPspFontData : public PhysicalFontFace
{
private:
enum { PSPFD_MAGIC = 0xb5bf01f0 };
@@ -553,15 +553,15 @@ private:
public:
ImplPspFontData( const psp::FastPrintFontInfo& );
virtual sal_IntPtr GetFontId() const { return mnFontId; }
- virtual ImplFontData* Clone() const { return new ImplPspFontData( *this ); }
+ virtual PhysicalFontFace* Clone() const { return new ImplPspFontData( *this ); }
virtual ImplFontEntry* CreateFontInstance( FontSelectPattern& ) const;
- static bool CheckFontData( const ImplFontData& r ) { return r.CheckMagic( PSPFD_MAGIC ); }
+ static bool CheckFontData( const PhysicalFontFace& r ) { return r.CheckMagic( PSPFD_MAGIC ); }
};
//--------------------------------------------------------------------------
ImplPspFontData::ImplPspFontData( const psp::FastPrintFontInfo& rInfo )
-: ImplFontData( GenPspGraphics::Info2DevFontAttributes(rInfo), PSPFD_MAGIC ),
+: PhysicalFontFace( GenPspGraphics::Info2DevFontAttributes(rInfo), PSPFD_MAGIC ),
mnFontId( rInfo.m_nID )
{}
@@ -1040,7 +1040,7 @@ SalLayout* GenPspGraphics::GetTextLayout( ImplLayoutArgs& rArgs, int nFallbackLe
sal_Bool GenPspGraphics::CreateFontSubset(
const rtl::OUString& rToFile,
- const ImplFontData* pFont,
+ const PhysicalFontFace* pFont,
sal_Int32* pGlyphIDs,
sal_uInt8* pEncoding,
sal_Int32* pWidths,
@@ -1052,7 +1052,7 @@ sal_Bool GenPspGraphics::CreateFontSubset(
// font since they are the only ones left after the PDF
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
// be to have the GlyphCache search for the ImplFontData pFont
psp::fontID aFont = pFont->GetFontId();
psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -1068,20 +1068,20 @@ sal_Bool GenPspGraphics::CreateFontSubset(
//--------------------------------------------------------------------------
-const Ucs2SIntMap* GenPspGraphics::GetFontEncodingVector( const ImplFontData* pFont, const Ucs2OStrMap** pNonEncoded )
+const Ucs2SIntMap* GenPspGraphics::GetFontEncodingVector( const PhysicalFontFace* pFont, const Ucs2OStrMap** pNonEncoded )
{
// in this context the pFont->GetFontId() is a valid PSP
// font since they are the only ones left after the PDF
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
// be to have the GlyphCache search for the ImplFontData pFont
psp::fontID aFont = pFont->GetFontId();
return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
}
//--------------------------------------------------------------------------
-void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
+void GenPspGraphics::GetGlyphWidths( const PhysicalFontFace* pFont,
bool bVertical,
Int32Vector& rWidths,
Ucs2UIntMap& rUnicodeEnc )
@@ -1090,7 +1090,7 @@ void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
// font since they are the only ones left after the PDF
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
// be to have the GlyphCache search for the ImplFontData pFont
psp::fontID aFont = pFont->GetFontId();
GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
}
@@ -1436,13 +1436,13 @@ void GenPspGraphics::FreeEmbedFontData( const void* pData, long nLen )
DoFreeEmbedFontData( pData, nLen );
}
-const void* GenPspGraphics::GetEmbedFontData( const ImplFontData* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
+const void* GenPspGraphics::GetEmbedFontData( const PhysicalFontFace* pFont, const sal_Ucs* pUnicodes, sal_Int32* pWidths, FontSubsetInfo& rInfo, long* pDataLen )
{
// in this context the pFont->GetFontId() is a valid PSP
// font since they are the only ones left after the PDF
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
// be to have the GlyphCache search for the ImplFontData pFont
psp::fontID aFont = pFont->GetFontId();
return DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );
}
@@ -1052,7 +1052,7 @@ sal_Bool GenPspGraphics::CreateFontSubset(
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
- // be to have the GlyphCache search for the ImplFontData pFont
+ // be to have the GlyphCache search for the PhysicalFontFace pFont
psp::fontID aFont = pFont->GetFontId();
psp::PrintFontManager& rMgr = psp::PrintFontManager::get();
@@ -1068,20 +1068,20 @@ sal_Bool GenPspGraphics::CreateFontSubset(
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
- // be to have the GlyphCache search for the ImplFontData pFont
+ // be to have the GlyphCache search for the PhysicalFontFace pFont
psp::fontID aFont = pFont->GetFontId();
return GenPspGraphics::DoGetFontEncodingVector( aFont, pNonEncoded );
@@ -1090,7 +1090,7 @@ void GenPspGraphics::GetGlyphWidths( const ImplFontData* pFont,
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
- // be to have the GlyphCache search for the ImplFontData pFont
+ // be to have the GlyphCache search for the PhysicalFontFace pFont
psp::fontID aFont = pFont->GetFontId();
GenPspGraphics::DoGetGlyphWidths( aFont, bVertical, rWidths, rUnicodeEnc );
@@ -1436,13 +1436,13 @@ void GenPspGraphics::FreeEmbedFontData( const void* pData, long nLen )
// export has filtered its list of subsettable fonts (for
// which this method was created). The correct way would
- // be to have the GlyphCache search for the ImplFontData pFont
+ // be to have the GlyphCache search for the PhysicalFontFace pFont
psp::fontID aFont = pFont->GetFontId();
return DoGetEmbedFontData( aFont, pUnicodes, pWidths, rInfo, pDataLen );